@@ -1,12 +1,18 @@
 import logging
 import os
 from collections import OrderedDict
+from typing import List
 
+from dateutil.parser import parse
+
+from great_expectations.core import ExpectationSuiteValidationResult, RunIdentifier
 from great_expectations.data_context.util import instantiate_class_from_config
 from great_expectations.exceptions import ClassInstantiationError
 from great_expectations.render.util import num_to_str
 
-from ...core.id_dict import BatchKwargs
+from ...validation_operators.types.validation_operator_result import (
+    ValidationOperatorResult,
+)
 from ..types import (
     CollapseContent,
     RenderedDocumentContent,
@@ -23,7 +29,13 @@ logger = logging.getLogger(__name__)
 
 
 class ValidationResultsPageRenderer(Renderer):
-    def __init__(self, column_section_renderer=None):
+    def __init__(self, column_section_renderer=None, run_info_at_end: bool = False):
+        """
+        Args:
+            column_section_renderer:
+            run_info_at_end: Move the run info (Info, Batch Markers, Batch Kwargs) to the end
+                of the rendered output rather than after Statistics.
+        """
         super().__init__()
         if column_section_renderer is None:
             column_section_renderer = {
@@ -43,10 +55,40 @@ class ValidationResultsPageRenderer(Renderer):
                 package_name=None,
                 class_name=column_section_renderer["class_name"],
             )
+        self.run_info_at_end = run_info_at_end
 
-    def render(self, validation_results):
+    def render_validation_operator_result(
+        self, validation_operator_result: ValidationOperatorResult
+    ) -> List[RenderedDocumentContent]:
+        """
+        Render a ValidationOperatorResult which can have multiple ExpectationSuiteValidationResult
+
+        Args:
+            validation_operator_result: ValidationOperatorResult
+
+        Returns:
+            List[RenderedDocumentContent]
+        """
+        return [
+            self.render(validation_result)
+            for validation_result in validation_operator_result.list_validation_results()
+        ]
+
+    def render(self, validation_results: ExpectationSuiteValidationResult):
         run_id = validation_results.meta["run_id"]
-        batch_id = BatchKwargs(validation_results.meta["batch_kwargs"]).to_id()
+        if isinstance(run_id, str):
+            try:
+                run_time = parse(run_id).strftime("%Y-%m-%dT%H:%M:%S.%fZ")
+            except (ValueError, TypeError):
+                run_time = "__none__"
+            run_name = run_id
+        elif isinstance(run_id, dict):
+            run_name = run_id.get("run_name") or "__none__"
+            run_time = run_id.get("run_time") or "__none__"
+        elif isinstance(run_id, RunIdentifier):
+            run_name = run_id.run_name or "__none__"
+            run_time = run_id.run_time.strftime("%Y-%m-%dT%H:%M:%S.%fZ")
+
         expectation_suite_name = validation_results.meta["expectation_suite_name"]
         batch_kwargs = validation_results.meta.get("batch_kwargs")
 
@@ -114,7 +156,8 @@ class ValidationResultsPageRenderer(Renderer):
             }
         )
 
-        overview_content_blocks.append(collapse_content_block)
+        if not self.run_info_at_end:
+            overview_content_blocks.append(collapse_content_block)
 
         sections = [
             RenderedSectionContent(
@@ -137,14 +180,42 @@ class ValidationResultsPageRenderer(Renderer):
             for column in ordered_columns
         ]
 
+        if self.run_info_at_end:
+            sections += [
+                RenderedSectionContent(
+                    **{
+                        "section_name": "Run Info",
+                        "content_blocks": collapse_content_blocks,
+                    }
+                )
+            ]
+
+        data_asset_name = batch_kwargs.get("data_asset_name")
+        # Determine whether we have a custom run_name
+        try:
+            run_name_as_time = parse(run_name)
+        except ValueError:
+            run_name_as_time = None
+        try:
+            run_time_datetime = parse(run_time)
+        except ValueError:
+            run_time_datetime = None
+
+        include_run_name: bool = False
+        if run_name_as_time != run_time_datetime and run_name_as_time != "__none__":
+            include_run_name = True
+
+        page_title = "Validations / " + expectation_suite_name
+        if data_asset_name:
+            page_title += " / " + data_asset_name
+        if include_run_name:
+            page_title += " / " + run_name
+        page_title += " / " + run_time
+
         return RenderedDocumentContent(
             **{
                 "renderer_type": "ValidationResultsPageRenderer",
-                "page_title": expectation_suite_name
-                + " / "
-                + run_id
-                + " / "
-                + batch_id,
+                "page_title": page_title,
                 "batch_kwargs": batch_kwargs,
                 "expectation_suite_name": expectation_suite_name,
                 "sections": sections,
@@ -157,7 +228,7 @@ class ValidationResultsPageRenderer(Renderer):
         success = validation_results.success
         expectation_suite_name = validation_results.meta["expectation_suite_name"]
         expectation_suite_path_components = (
-            [".." for _ in range(len(expectation_suite_name.split(".")) + 2)]
+            [".." for _ in range(len(expectation_suite_name.split(".")) + 3)]
             + ["expectations"]
             + expectation_suite_name.split(".")
         )
@@ -165,10 +236,14 @@ class ValidationResultsPageRenderer(Renderer):
             os.path.join(*expectation_suite_path_components) + ".html"
         )
         if success:
-            success = '<i class="fas fa-check-circle text-success" aria-hidden="true"></i> Succeeded'
+            success = "Succeeded"
+            html_success_icon = (
+                '<i class="fas fa-check-circle text-success" aria-hidden="true"></i>'
+            )
         else:
-            success = (
-                '<i class="fas fa-times text-danger" aria-hidden="true"></i> Failed'
+            success = "Failed"
+            html_success_icon = (
+                '<i class="fas fa-times text-danger" aria-hidden="true"></i>'
             )
         return RenderedHeaderContent(
             **{
@@ -187,12 +262,13 @@ class ValidationResultsPageRenderer(Renderer):
                     **{
                         "content_block_type": "string_template",
                         "string_template": {
-                            "template": "${suite_title} ${expectation_suite_name}\n${status_title} ${success}",
+                            "template": "${suite_title} ${expectation_suite_name}\n${status_title} ${html_success_icon} ${success}",
                             "params": {
                                 "suite_title": "Expectation Suite:",
                                 "status_title": "Status:",
                                 "expectation_suite_name": expectation_suite_name,
                                 "success": success,
+                                "html_success_icon": html_success_icon,
                             },
                             "styling": {
                                 "params": {
@@ -218,7 +294,22 @@ class ValidationResultsPageRenderer(Renderer):
     @classmethod
     def _render_validation_info(cls, validation_results):
         run_id = validation_results.meta["run_id"]
-        ge_version = validation_results.meta["great_expectations.__version__"]
+        if isinstance(run_id, str):
+            try:
+                run_time = parse(run_id).strftime("%Y-%m-%dT%H:%M:%S.%fZ")
+            except (ValueError, TypeError):
+                run_time = "__none__"
+            run_name = run_id
+        elif isinstance(run_id, dict):
+            run_name = run_id.get("run_name") or "__none__"
+            run_time = run_id.get("run_time") or "__none__"
+        elif isinstance(run_id, RunIdentifier):
+            run_name = run_id.run_name or "__none__"
+            run_time = run_id.run_time.strftime("%Y-%m-%dT%H:%M:%S.%fZ")
+        # TODO: Deprecate "great_expectations.__version__"
+        ge_version = validation_results.meta.get(
+            "great_expectations_version"
+        ) or validation_results.meta.get("great_expectations.__version__")
 
         return RenderedTableContent(
             **{
@@ -235,11 +326,18 @@ class ValidationResultsPageRenderer(Renderer):
                 ),
                 "table": [
                     ["Great Expectations Version", ge_version],
-                    ["Run ID", run_id],
+                    ["Run Name", run_name],
+                    ["Run Time", run_time],
                 ],
                 "styling": {
                     "classes": ["col-12", "table-responsive", "mt-1"],
-                    "body": {"classes": ["table", "table-sm"]},
+                    "body": {
+                        "classes": ["table", "table-sm"],
+                        "styles": {
+                            "margin-bottom": "0.5rem !important",
+                            "margin-top": "0.5rem !important",
+                        },
+                    },
                 },
             }
         )
@@ -327,8 +425,13 @@ class ValidationResultsPageRenderer(Renderer):
                     ),
                     "table": table_rows,
                     "styling": {
-                        "classes": ["col-6", "table-responsive", "mt-1"],
-                        "body": {"classes": ["table", "table-sm"]},
+                        "body": {
+                            "classes": ["table", "table-sm"],
+                            "styles": {
+                                "margin-bottom": "0.5rem !important",
+                                "margin-top": "0.5rem !important",
+                            },
+                        }
                     },
                 }
             )
@@ -371,7 +474,13 @@ class ValidationResultsPageRenderer(Renderer):
                 "table": table_rows,
                 "styling": {
                     "classes": ["col-6", "table-responsive", "mt-1", "p-1"],
-                    "body": {"classes": ["table", "table-sm"]},
+                    "body": {
+                        "classes": ["table", "table-sm"],
+                        "styles": {
+                            "margin-bottom": "0.5rem !important",
+                            "margin-top": "0.5rem !important",
+                        },
+                    },
                 },
             }
         )
@@ -437,7 +546,7 @@ class ExpectationSuitePageRenderer(Renderer):
         return RenderedDocumentContent(
             **{
                 "renderer_type": "ExpectationSuitePageRenderer",
-                "page_title": expectation_suite_name,
+                "page_title": "Expectations / " + expectation_suite_name,
                 "expectation_suite_name": expectation_suite_name,
                 "utm_medium": "expectation-suite-page",
                 "sections": sections,
@@ -489,7 +598,10 @@ class ExpectationSuitePageRenderer(Renderer):
     @classmethod
     def _render_expectation_suite_info(cls, expectations):
         expectation_suite_name = expectations.expectation_suite_name
-        ge_version = expectations.meta["great_expectations.__version__"]
+        # TODO: Deprecate "great_expectations.__version__"
+        ge_version = expectations.meta.get(
+            "great_expectations_version"
+        ) or expectations.meta.get("great_expectations.__version__")
 
         return RenderedTableContent(
             **{
@@ -510,7 +622,13 @@ class ExpectationSuitePageRenderer(Renderer):
                 ],
                 "styling": {
                     "classes": ["col-12", "table-responsive", "mt-1"],
-                    "body": {"classes": ["table", "table-sm"]},
+                    "body": {
+                        "classes": ["table", "table-sm"],
+                        "styles": {
+                            "margin-bottom": "0.5rem !important",
+                            "margin-top": "0.5rem !important",
+                        },
+                    },
                 },
             }
         )
@@ -656,6 +774,19 @@ class ProfilingResultsPageRenderer(Renderer):
 
     def render(self, validation_results):
         run_id = validation_results.meta["run_id"]
+        if isinstance(run_id, str):
+            try:
+                run_time = parse(run_id).strftime("%Y-%m-%dT%H:%M:%S.%fZ")
+            except (ValueError, TypeError):
+                run_time = "__none__"
+            run_name = run_id
+        elif isinstance(run_id, dict):
+            run_name = run_id.get("run_name") or "__none__"
+            run_time = run_id.get("run_time") or "__none__"
+        elif isinstance(run_id, RunIdentifier):
+            run_name = run_id.run_name or "__none__"
+            run_time = run_id.run_time.strftime("%Y-%m-%dT%H:%M:%S.%fZ")
+
         expectation_suite_name = validation_results.meta["expectation_suite_name"]
         batch_kwargs = validation_results.meta.get("batch_kwargs")
 
@@ -674,13 +805,32 @@ class ProfilingResultsPageRenderer(Renderer):
             validation_results
         )
 
+        data_asset_name = batch_kwargs.get("data_asset_name")
+        # Determine whether we have a custom run_name
+        try:
+            run_name_as_time = parse(run_name)
+        except ValueError:
+            run_name_as_time = None
+        try:
+            run_time_datetime = parse(run_time)
+        except ValueError:
+            run_time_datetime = None
+
+        include_run_name: bool = False
+        if run_name_as_time != run_time_datetime and run_name_as_time != "__none__":
+            include_run_name = True
+
+        page_title = "Profiling Results / " + expectation_suite_name
+        if data_asset_name:
+            page_title += " / " + data_asset_name
+        if include_run_name:
+            page_title += " / " + run_name
+        page_title += " / " + run_time
+
         return RenderedDocumentContent(
             **{
                 "renderer_type": "ProfilingResultsPageRenderer",
-                "page_title": run_id
-                + "-"
-                + expectation_suite_name
-                + "-ProfilingResults",
+                "page_title": page_title,
                 "expectation_suite_name": expectation_suite_name,
                 "utm_medium": "profiling-results-page",
                 "batch_kwargs": batch_kwargs,
